@@ -13,7 +13,7 @@ Note that per https://spec.openapis.org/oas/v3.0.4.html#relative-references-in-a
 """
 
 import re
-from typing import Any, ClassVar, Optional, Self
+from typing import Any, ClassVar, Self
 
 from jsonschema.exceptions import ValidationError as JSONVSchemeValidationError
 from jsonschema.protocols import Validator as JSONSchemaValidator
@@ -94,7 +94,9 @@ class ReferenceObject(GenericObject):
     as per RFC6901.
     """
 
-    model_config = ConfigDict(extra="forbid", populate_by_name=True)
+    model_config: ClassVar[ConfigDict] = ConfigDict(
+        extra="forbid", populate_by_name=True
+    )
 
     ref: URI = Field(alias="$ref")
     _reference_uri: ClassVar[str] = (
@@ -225,7 +227,7 @@ class ExternalDocumentationObject(GenericObject):
 class PathsObject(GenericObject):
     """Validates the OpenAPI Specification paths object - §4.8.8"""
 
-    model_config = ConfigDict(extra="allow")
+    model_config: ClassVar[ConfigDict] = ConfigDict(extra="allow")
 
     @model_validator(mode="before")
     @classmethod
@@ -237,7 +239,7 @@ class PathsObject(GenericObject):
         Special-case specification extensions, which are also allowed.
         """
 
-        for field in data.keys():
+        for field in data:
             # Specification extensions
             if field.startswith("x-"):
                 continue
@@ -256,12 +258,12 @@ class OperationObject(GenericObject):
     description: str | CommonMark | None = None
     externalDocs: ExternalDocumentationObject | None = None
     operationId: str | None = None
-    parameters: list["ParameterObject | ReferenceObject"] | None = None
-    requestBody: Optional["RequestBodyObject | ReferenceObject"] = None
-    responses: "ResponsesObject"
-    callbacks: dict[str, "CallbackObject | ReferenceObject"] | None = None
+    parameters: list[ParameterObject | ReferenceObject] | None = None
+    requestBody: RequestBodyObject | ReferenceObject | None = None
+    responses: ResponsesObject
+    callbacks: dict[str, CallbackObject | ReferenceObject] | None = None
     deprecated: bool | None = False
-    security: list["SecurityRequirementObject"] | None = None
+    security: list[SecurityRequirementObject] | None = None
     servers: list[ServerObject] | None = None
 
     _reference_uri: ClassVar[str] = (
@@ -293,10 +295,10 @@ class ParameterObject(GenericObject):
     style: str | None = None
     explode: bool | None = None
     allowReserved: bool | None = None
-    schema_: Optional["SchemaObject | ReferenceObject"] = Field(alias="schema")
+    schema_: SchemaObject | ReferenceObject | None = Field(alias="schema")
     example: Any | None = None
-    examples: dict[str, "ExampleObject | ReferenceObject"] | None = None
-    content: dict[str, "MediaTypeObject"] | None = None
+    examples: dict[str, ExampleObject | ReferenceObject] | None = None
+    content: dict[str, MediaTypeObject] | None = None
     _reference_uri: ClassVar[str] = (
         "https://spec.openapis.org/oas/v3.0.4.html#parameter-object"
     )
@@ -341,7 +343,7 @@ class RequestBodyObject(GenericObject):
     """
 
     description: CommonMark | str | None = None
-    content: dict[str, "MediaTypeObject"]
+    content: dict[str, MediaTypeObject]
     required: bool | None = False
     _reference_uri: ClassVar[str] = (
         "https://spec.openapis.org/oas/v3.0.4.html#request-body-object"
@@ -354,13 +356,11 @@ class MediaTypeObject(GenericObject):
     Validates the OpenAPI Specification media type object - §4.8.14
     """
 
-    schema_: Optional["SchemaObject | ReferenceObject"] = Field(
-        alias="schema", default=None
-    )
+    schema_: SchemaObject | ReferenceObject | None = Field(alias="schema", default=None)
     # FIXME: Define example
     example: Any | None = None
     examples: dict[str, ExampleObject | ReferenceObject] | None = None
-    encoding: Optional["EncodingObject"] = None
+    encoding: EncodingObject | None = None
     _reference_uri: ClassVar[str] = (
         "https://spec.openapis.org/oas/v3.0.4.html#media-type-object"
     )
@@ -373,7 +373,7 @@ class EncodingObject(GenericObject):
     """
 
     contentType: str | None = None
-    headers: dict[str, "HeaderObject | ReferenceObject"] | None = None
+    headers: dict[str, HeaderObject | ReferenceObject] | None = None
     _reference_uri: ClassVar[str] = (
         "https://spec.openapis.org/oas/v3.0.4.html#encoding object-object"
     )
@@ -403,11 +403,11 @@ class ResponsesObject(GenericObject):
     Validates the OpenAPI Specification responses object - §4.8.16
     """
 
-    model_config = ConfigDict(
+    model_config: ClassVar[ConfigDict] = ConfigDict(
         extra="allow",
     )
 
-    default: Optional["ResponseObject | ReferenceObject"] = None
+    default: ResponseObject | ReferenceObject | None = None
     _reference_uri: ClassVar[str] = (
         "https://spec.openapis.org/oas/v3.0.4.html#responses-object"
     )
@@ -415,7 +415,7 @@ class ResponsesObject(GenericObject):
     @classmethod
     def _choose_model(
         cls, value: Any, field_name: str
-    ) -> "ReferenceObject | ResponseObject":
+    ) -> ReferenceObject | ResponseObject:
         """
         Choose the model to use for validation based on the type of value.
 
@@ -484,9 +484,9 @@ class ResponseObject(GenericObject):
     """
 
     description: str | CommonMark
-    headers: dict[str, "HeaderObject | ReferenceObject"] | None = None
+    headers: dict[str, HeaderObject | ReferenceObject] | None = None
     content: dict[str, MediaTypeObject] | None = None
-    links: dict[str, "LinkObject | ReferenceObject"] | None = None
+    links: dict[str, LinkObject | ReferenceObject] | None = None
     _reference_uri: ClassVar[str] = (
         "https://spec.openapis.org/oas/v3.0.4.html#response-object"
     )
@@ -498,7 +498,7 @@ class CallbackObject(GenericObject):
     Validates the OpenAPI Specification callback object - §4.8.18
     """
 
-    model_config = ConfigDict(extra="allow")
+    model_config: ClassVar[ConfigDict] = ConfigDict(extra="allow")
 
     # The keys are runtime expressions that resolve to a URL
     # The values are Response Objects or Reference Objects
@@ -508,7 +508,7 @@ class CallbackObject(GenericObject):
 
     @model_validator(mode="before")
     @classmethod
-    def validate_all_fields(cls, data: dict[str, Any]) -> dict[str, "PathItemObject"]:
+    def validate_all_fields(cls, data: dict[str, Any]) -> dict[str, PathItemObject]:
         """
         Validates the callback object.
         """
@@ -603,9 +603,7 @@ class HeaderObject(GenericObject):
     # Schema fields
     style: str | None = Field(default="simple")
     explode: bool | None = Field(default=False)
-    schema_: Optional["SchemaObject | ReferenceObject"] = Field(
-        alias="schema", default=None
-    )
+    schema_: SchemaObject | ReferenceObject | None = Field(alias="schema", default=None)
     example: JSONValue | None = None
     examples: dict[str, ExampleObject | ReferenceObject] | None = None
 
@@ -664,7 +662,7 @@ class SchemaObject(GenericObject):
     and validated through jsonschema.
     """
 
-    model_config = ConfigDict(
+    model_config: ClassVar[ConfigDict] = ConfigDict(
         populate_by_name=True,
         extra="allow",  # Allow all standard JSON Schema fields
     )
@@ -702,7 +700,7 @@ class SchemaObject(GenericObject):
             if isinstance(type_val, str) and type_val != "null":
                 schema_dict["type"] = [type_val, "null"]
             elif isinstance(type_val, list) and "null" not in type_val:
-                schema_dict["type"] = type_val + ["null"]
+                schema_dict["type"] = [*type_val, ["null"]]
 
         # 2. Validate the schema structure using jsonschema's meta-schema
         # Get the right validator based on the declared $schema or default
@@ -750,7 +748,7 @@ class OAuthFlowObject(GenericObject):
     authorizationUrl: URI | None = None
     tokenUrl: URI | None = None
     refreshUrl: URI | None = None
-    scopes: dict[str, str] = {}
+    scopes: dict[str, str] = Field(default={})
     _reference_uri: ClassVar[str] = (
         "https://spec.openapis.org/oas/v3.0.4.html#oauth-flow-object"
     )
@@ -958,7 +956,7 @@ class ComponentsObject(GenericObject):
                     f"Invalid type for '{field_name}': expected dict, got {type(value)}"
                 )
 
-            for key in value.keys():
+            for key in value:
                 if not re.match(pattern, key):
                     raise ValueError(
                         f"Invalid key '{key}' in '{field_name}': must match pattern {pattern}"  # noqa: E501
