@@ -13,7 +13,7 @@ Note that per https://spec.openapis.org/oas/v3.1.1.html#relative-references-in-a
 """
 
 import re
-from typing import Any, ClassVar, Optional, Self
+from typing import Any, ClassVar, Self
 
 from jsonschema.exceptions import ValidationError as JSONVSchemeValidationError
 from jsonschema.protocols import Validator as JSONSchemaValidator
@@ -104,7 +104,7 @@ class LicenceObject(GenericObject):
             except AmatiValueError:
                 Logger.log(
                     {
-                        "msg": f"{str(self.url)} is not a valid SPDX URL",
+                        "msg": f"{self.url} is not a valid SPDX URL",
                         "type": "warning",
                         "loc": (self.__class__.__name__,),
                         "input": self.url,
@@ -142,7 +142,9 @@ class ReferenceObject(GenericObject):
     as per RFC6901.
     """
 
-    model_config = ConfigDict(extra="forbid", populate_by_name=True)
+    model_config: ClassVar[ConfigDict] = ConfigDict(
+        extra="forbid", populate_by_name=True
+    )
 
     ref: URI = Field(alias="$ref")
     summary: str | None
@@ -233,12 +235,12 @@ class OperationObject(GenericObject):
     description: str | CommonMark | None = None
     externalDocs: ExternalDocumentationObject | None = None
     operationId: str | None = None
-    parameters: list["ParameterObject | ReferenceObject"] | None = None
-    requestBody: Optional["RequestBodyObject | ReferenceObject"] = None
-    responses: Optional["ResponsesObject"] = None
-    callbacks: dict[str, "CallbackObject | ReferenceObject"] | None = None
+    parameters: list[ParameterObject | ReferenceObject] | None = None
+    requestBody: RequestBodyObject | ReferenceObject | None = None
+    responses: ResponsesObject | None = None
+    callbacks: dict[str, CallbackObject | ReferenceObject] | None = None
     deprecated: bool | None = False
-    security: list["SecurityRequirementObject"] | None = None
+    security: list[SecurityRequirementObject] | None = None
     servers: list[ServerObject] | None = None
 
     _reference_uri: ClassVar[str] = (
@@ -270,10 +272,10 @@ class ParameterObject(GenericObject):
     style: str | None = None
     explode: bool | None = None
     allowReserved: bool | None = None
-    schema_: Optional["SchemaObject"] = Field(alias="schema")
+    schema_: SchemaObject | None = Field(alias="schema")
     example: Any | None = None
-    examples: dict[str, "ExampleObject | ReferenceObject"] | None = None
-    content: dict[str, "MediaTypeObject"] | None = None
+    examples: dict[str, ExampleObject | ReferenceObject] | None = None
+    content: dict[str, MediaTypeObject] | None = None
     _reference_uri: ClassVar[str] = (
         "https://spec.openapis.org/oas/v3.1.1.html#parameter-object"
     )
@@ -317,11 +319,11 @@ class MediaTypeObject(GenericObject):
     Validates the OpenAPI Specification media type object - §4.8.14
     """
 
-    schema_: Optional["SchemaObject"] = Field(alias="schema", default=None)
+    schema_: SchemaObject | None = Field(alias="schema", default=None)
     # FIXME: Define example
     example: Any | None = None
     examples: dict[str, ExampleObject | ReferenceObject] | None = None
-    encoding: Optional["EncodingObject"] = None
+    encoding: EncodingObject | None = None
     _reference_uri: ClassVar[str] = (
         "https://spec.openapis.org/oas/v3.1.1.html#media-type-object"
     )
@@ -336,7 +338,7 @@ class SchemaObject(GenericObject):
     and validated through jsonschema.
     """
 
-    model_config = ConfigDict(
+    model_config: ClassVar[ConfigDict] = ConfigDict(
         populate_by_name=True,
         extra="allow",  # Allow all standard JSON Schema fields
     )
@@ -374,7 +376,7 @@ class SchemaObject(GenericObject):
             if isinstance(type_val, str) and type_val != "null":
                 schema_dict["type"] = [type_val, "null"]
             elif isinstance(type_val, list) and "null" not in type_val:
-                schema_dict["type"] = type_val + ["null"]
+                schema_dict["type"] = [*type_val, ["null"]]
 
         # 2. Validate the schema structure using jsonschema's meta-schema
         # Get the right validator based on the declared $schema or default
@@ -482,7 +484,7 @@ class ComponentsObject(GenericObject):
                     f"Invalid type for '{field_name}': expected dict, got {type(value)}"
                 )
 
-            for key in value.keys():
+            for key in value:
                 if not re.match(pattern, key):
                     raise ValueError(
                         f"Invalid key '{key}' in '{field_name}': must match pattern {pattern}"  # noqa: E501
